[![@wq/map-gl][logo]][docs]

**@wq/map-gl** is a plugin for [@wq/app] that provides integration with [Mapbox GL JS] (for web) and the Mapbox Map SDK for [Android](mapbox-android) and [iOS](mapbox-ios).   When used together with [@wq/map], @wq/map-gl can leverage the [wq configuration object][config] to generate interactive maps for pages rendered via @wq/app.  The generated maps can automatically download and display GeoJSON data rendered by [wq.db's REST API][wq.db] or any third party service.

### [Documentation][docs]

[**Installation**][installation]
&bull;
[**API**][api]
&bull;
[Configuration][configuration]
&bull;
[Components][components]

[logo]: https://wq.io/images/@wq/map-gl.svg
[docs]: https://wq.io/@wq/map-gl
[installation]: https://wq.io/@wq/map-gl#installation
[api]: https://wq.io/@wq/map-gl#api
[configuration]: https://wq.io/@wq/map-gl#configuration
[components]: https://wq.io/@wq/map-gl#components

[@wq/app]: https://wq.io/@wq/app
[@wq/map]: https://wq.io/@wq/map
[config]: https://wq.io/config
[wq.db]: https://wq.io/wq.db/

[Mapbox GL JS]: https://docs.mapbox.com/mapbox-gl-js/
[mapbox-android]: https://docs.mapbox.com/android/maps/overview/
[mapbox-ios]: https://docs.mapbox.com/ios-sdk/maps/overview/
